==> manim_editor-0.3.2.tar.gz: manim_editor-0.3.2/README.md <==
<p align="center">
    <a href="#"><img src="https://raw.githubusercontent.com/ManimCommunity/manim_editor/main/manim_editor/app/static/img/banner.png"></a>
    <br />
    <br />
    <a href="https://pypi.org/project/manim-editor/"><img src="https://img.shields.io/pypi/v/manim-editor.svg?style=flat&logo=pypi" alt="PyPI Latest Release"></a>
    <a href="https://docs.editor.manim.community/en/stable/"><img src='https://readthedocs.org/projects/manim-editor/badge/?version=stable' alt='Documentation Status' /></a>
    <a href="http://choosealicense.com/licenses/mit/"><img src="https://img.shields.io/badge/license-MIT-red.svg?style=flat" alt="MIT License"></a>
    <a href="https://github.com/ManimCommunity/manim_editor/actions/workflows/build_pages.yml"><img src="https://github.com/ManimCommunity/manim_editor/actions/workflows/build_pages.yml/badge.svg" alt="MIT License"></a>
    <br />
    <br />
    <i>Editor and Presenter for Manim Generated Content.</i>
</p>
<hr />

Take a look at the [Working Example](https://ManimCommunity.github.io/manim_editor/).
More information can be found on the [documentation](https://docs.editor.manim.community/en/stable/).

These Browsers are supported:
- Firefox
- Chrome/Chromium-Based
- Edge

## Create a Project

![create_project](https://raw.githubusercontent.com/ManimCommunity/manim_editor/main/docs/source/_static/create_project.gif)

## Export a Project as a Presentation

![export_presenter](https://raw.githubusercontent.com/ManimCommunity/manim_editor/main/docs/source/_static/export_presenter.gif)

==> manim_editor-0.3.7.tar.gz: manim_editor-0.3.7/README.md <==
<p align="center">
    <a href="#"><img src="https://raw.githubusercontent.com/ManimCommunity/manim_editor/main/manim_editor/app/static/img/banner.png"></a>
    <br />
    <br />
    <a href="https://pypi.org/project/manim-editor/"><img src="https://img.shields.io/pypi/v/manim-editor.svg?style=flat&logo=pypi" alt="PyPI Latest Release"></a>
    <a href="https://docs.editor.manim.community/en/stable/"><img src='https://readthedocs.org/projects/manim-editor/badge/?version=stable' alt='Documentation Status' /></a>
    <a href="http://choosealicense.com/licenses/mit/"><img src="https://img.shields.io/badge/license-MIT-red.svg?style=flat" alt="MIT License"></a>
    <a href="https://github.com/ManimCommunity/manim_editor/actions/workflows/build_pages.yml"><img src="https://github.com/ManimCommunity/manim_editor/actions/workflows/build_pages.yml/badge.svg" alt="MIT License"></a>
    <br />
    <br />
    <i>Editor and Presenter for Manim Generated Content.</i>
</p>
<hr />

Take a look at the [Working Example](https://ManimCommunity.github.io/manim_editor/).
More information can be found in the [documentation](https://docs.editor.manim.community/en/stable/).

These Browsers are supported:
- Firefox
- Chrome/Chromium-Based
- Edge

## Create a Project

![create_project](https://raw.githubusercontent.com/ManimCommunity/manim_editor/main/docs/source/_static/create_project.gif)

## Export a Project as a Presentation

![export_presenter](https://raw.githubusercontent.com/ManimCommunity/manim_editor/main/docs/source/_static/export_presenter.gif)
